measure_it
==========

`measure_it <http://github.com/wearpants/measure_it>`__ provides timing and counting for iterators (and other code segments).

:author: Pete Fein <pete@wearpants.org>
:license: BSD
:versions: Python 2.7 & 3
:source: https://github.com/wearpants/measure_it
:homepage: https://measure_it.readthedocs.org/en/latest/

.. toctree::
    :maxdepth: 2

    installation
    basic_use
    output
    api
    incompatibilities
    future
    changelog